@@ -13,7 +13,7 @@ as.yearmon.yearqtr <- function(x, frac = 0, ...) {
 as.yearmon.dates <- 
 as.yearmon.Date <- 
 as.yearmon.POSIXt <- function(x, ...) as.yearmon(with(as.POSIXlt(x, tz="GMT"), 1900 + year + mon/12))
-# as.jul.yearmon <- function(x, ...) jul(as.Date(x, ...)) # jul is from fame pkg
+# as.jul.yearmon <- function(x, ...) jul(as.Date(x, ...)) # jul is from tis pkg
 as.yearmon.timeDate <-
 as.yearmon.jul <- function(x, ...) as.yearmon(as.Date(x, ...))
 as.yearmon.factor <- function(x, ...) as.yearmon(as.character(x), ...)
@@ -113,7 +113,7 @@ Ops.yearmon <- function(e1, e2) {
     e1 <- as.numeric(as.yearmon(e1))
     e2 <- as.numeric(as.yearmon(e2))
     rval <- NextMethod(.Generic)
-    if(is.numeric(rval)) rval <- as.yearmon(rval)
+    rval <- yearmon(rval)
     return(rval)
 }
 
@@ -127,7 +127,7 @@ Ops.yearmon <- function(e1, e2) {
         return(as.numeric(e1) - as.numeric(e2))
     if (!is.null(attr(e2, "class"))) 
       stop("can only subtract yearmon objects and numbers from yearmon objects")
-    structure(unclass(as.yearmon(e1)) - e2, class = "yearmon")
+    yearmon(unclass(e1) - e2)
 }
 
 is.numeric.yearmon <- function(x) FALSE
@@ -202,8 +202,8 @@ range.yearmon <- function(..., na.rm = FALSE) {
 	as.yearmon(range.default(..., na.rm = na.rm))
 }
 
-unique.yearmon <- function(..., incomparables = FALSE) {
-	as.yearmon(range.default(..., incomparables = incomparables))
+unique.yearmon <- function(x, incomparables = FALSE, ...) {
+	as.yearmon(unique.default(x, incomparables = incomparables, ...))
 }
 
 
